@@ -21,6 +21,7 @@ but emits json instead of plain text.
 
 import json
 import os
+import signal
 import subprocess
 import sys
 import time
@@ -335,6 +336,7 @@ class Symbolizer(Subcommand):
         src_dir_to_move,
         dsym_hint,
         symbolizer_path,
+        live,
     ):
         self.output_format = output_format
         self.host = host
@@ -343,8 +345,51 @@ class Symbolizer(Subcommand):
         self.src_dir_to_move = src_dir_to_move
         self.dsym_hint = dsym_hint
         self.symbolizer_path = symbolizer_path
+        self.live = live
+
+    def substitute_stdin(self, resolver):
+        """Accept stdin stream as source of logs and symbolize it."""
+
+        # Ignore Ctrl-C. When the process feeding the pipe exits, `stdin` will be closed.
+        signal.signal(signal.SIGINT, signal.SIG_IGN)
+
+        print("Live mode activated, waiting for input...")
+        while True:
+            backtrace_indicator = '{"backtrace":'
+            line = sys.stdin.readline()
+            if not line:
+                return
+
+            line = line.strip()
+
+            if "Frame: 0x" in line:
+                continue
+
+            if backtrace_indicator in line:
+                backtrace_index = line.index(backtrace_indicator)
+                prefix = line[:backtrace_index]
+                backtrace = line[backtrace_index:]
+                trace_doc = json.loads(backtrace)
+                if not trace_doc["backtrace"]:
+                    print("Trace is empty, skipping...")
+                    continue
+                frames = self.symbolize_frames(
+                    trace_doc, resolver, self.symbolizer_path, [], self.output_format
+                )
+                print(prefix)
+                print("Symbolizing...")
+                self.classic_output(frames, sys.stdout, indent=2)
+            else:
+                print(line)
 
     def execute(self):
+        resolver = PathResolver(host=self.host, cache_dir=self.cache_dir)
+
+        if self.live:
+            print("Entering live mode")
+            self.substitute_stdin(resolver)
+            sys.exit(0)
+
         # Skip over everything before the first '{' since it is likely to be log line prefixes.
         # Additionally, using raw_decode() to ignore extra data after the closing '}' to allow maximal
         # sloppiness in copy-pasting input.
@@ -383,8 +428,6 @@ class Symbolizer(Subcommand):
         if self.output_format == "classic":
             output_fn = self.classic_output
 
-        resolver = PathResolver(host=self.host, cache_dir=self.cache_dir)
-
         frames = self.preprocess_frames(resolver, trace_doc, self.input_format)
 
         if self.src_dir_to_move and resolver.mci_build_dir is not None:
@@ -466,7 +509,15 @@ class Symbolizer(Subcommand):
             frames = self.preprocess_frames(dbg_path_resolver, trace_doc, input_format)
 
         if not symbolizer_path:
-            symbolizer_path = os.environ.get("MONGOSYMB_SYMBOLIZER_PATH", "llvm-symbolizer")
+            symbolizer_path_env = "MONGOSYMB_SYMBOLIZER_PATH"
+            default_symbolizer_path = "llvm-symbolizer"
+            symbolizer_path = os.environ.get(symbolizer_path_env)
+            if not symbolizer_path:
+                print(
+                    f"Env value for '{symbolizer_path_env}' not found, using '{default_symbolizer_path}' "
+                    f"as a defualt executable path."
+                )
+                symbolizer_path = default_symbolizer_path
 
         symbolizer_args = [symbolizer_path]
         for dh in dsym_hint:
@@ -560,6 +611,7 @@ class SymbolizerPlugin(PluginInterface):
             src_dir_to_move=parsed_args.src_dir_to_move,
             dsym_hint=parsed_args.dsym_hint,
             symbolizer_path=parsed_args.symbolizer_path,
+            live=parsed_args.live,
         )
 
     def add_subcommand(self, subparsers):
@@ -580,6 +632,8 @@ class SymbolizerPlugin(PluginInterface):
             default=None,
             help="Specify a src dir to move to /data/mci/{original_buildid}/src",
         )
+
+        parser.add_argument("--live", action="store_true")
         parser.add_argument(
             "--host", default="", help="URL of web service running the API to get debug symbol URL"
         )
